{*******************************************************}
{                                                       }
{      TLog                                             }
{      Log Component Manager                            }
{                                                       }
{      Rel 1.0                                          }
{      Date 07/05/1998                                  }
{      Copyright (c) 1998 By Gianni Giorgetti Soft      }
{                                                       }
{*******************************************************}

unit MyLog;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, StdCtrls, ExtCtrls,
  DsgnIntf, Menus, ComCtrls, Grids;

const
  DEFAULT_SEPARATOR : char = ';';
  VERSION_ID = '1.0';

type
  TLogMessages = (lmInfo, lmError, lmWarning, lmProcess);
  TLogFields = (lfString, lfNumber, lfComputerName, lfUserName, lfAppName, lfDateStamp, lfTimeStamp);

//******************************************************************************
//  Type:		TLogsItem
//  Ver: 		1.0
//  Purpose:      	TCollectionItem Class for TLog Component
//******************************************************************************
  TLog = class;

  TLogItem = class(TCollectionItem)
  private
    { Private declarations }
    FDisplayLabel: string;
    FFieldKind: TLogFields;
    FFieldName: string;
    FWidth: integer;
    function GetDisplayName: string; override;
  public
    { Public declarations }
    constructor Create(Collection: TCollection); override;
    destructor Destroy; override;
  published
   { Published declarations }
    property DisplayLabel: string read FDisplayLabel write FDisplayLabel;
    property FieldName: string read FFieldName write FFieldName;
    property FieldKind: TLogFields read FFieldKind write FFieldKind;
    property Width: integer read FWidth write FWidth;
  end; // TLogItem


//******************************************************************************
//  Type:		TLogsItem
//  Ver: 		1.0
//  Purpose:            TCollection Class for TLog Component
//******************************************************************************
  TLogItems = class(TCollection)
  private
    { Private declarations }
    FLog: TLog;
    function GetItem(Index: Integer): TLogItem;
    procedure SetItem(Index: Integer; Value: TLogItem);
  protected
    { Protected declarations }
    function GetOwner: TPersistent; override;
  public
    { Public declarations }
    constructor Create(Log: TLog);
    function Add: TLogItem;
    property Items[Index: Integer]: TLogItem read GetItem write SetItem; default;
  end; // TLogItems


//******************************************************************************
//  Type:		TLog
//  Ver: 		1.0
//  Purpose:            TLog Class
//******************************************************************************
  TLog = class(TComponent)
  private
    { Private declarations }
    FInformation: Cardinal;
    FCSVSeparator: char;
    FDeleteOnChange: boolean;
    FFileName: TFileName;
    FHeight: integer;
    FItems: TLogItems;
    FWidth: integer;
    procedure SetItems (Value: TLogItems);
    procedure SetFileName (Value: TFileName);
    function ReadLog (Grid: TStringGrid): boolean;
    function WriteLog (LogMessage: integer; Values: array of string): boolean;
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;

    procedure ViewLog;
    function WriteLogInfo (Values : array of string): boolean;
    function WriteLogError (Values : array of string): boolean;
    function WriteLogWarning (Values : array of string): boolean;
    function WriteLogProcess (Values : array of string): boolean;
  published
    { Published declarations }
    property DeleteOnChange: boolean read FDeleteOnChange write FDeleteOnChange;
    property FileName: TFileName read FFileName write SetFileName;
    property FormHeight: integer read FHeight write FHeight;
    property FormWidth: integer read FWidth write FWidth;
    property Information: Cardinal read FInformation write FInformation;
    property Items: TLogItems read Fitems write SetItems;
    property Separator: char read FCsvSeparator write FCsvSeparator;
  end; // TLog


//******************************************************************************
//  Type:		TInformationProperty
//  Ver:  		1.1
//  Purpose:            TPropertyEditor for TLog component
//******************************************************************************
TInformationProperty = class(TPropertyEditor)
  public
    { Public declarations }
    function GetAttributes: TPropertyAttributes; override;
    function GetName: string; override;
    function GetValue: string; override;
    procedure Edit; override;
  end; // TInformationProperty


//******************************************************************************
//  Type:		TInformationEditor
//  Ver:  		1.1
//  Purpose:            TComponentEditor for TLog component
//******************************************************************************
TInformationEditor = class(TComponentEditor)
  public
    { Public declarations }
    function GetVerbCount: Integer; override;
    function GetVerb(Index: Integer): string; override;
    procedure ExecuteVerb(Index: Integer); override;
    procedure About;
    procedure Edit; override;
  end; // TInformationEditor

//******************************************************************************
//  Type:		TfmLog
//  Ver: 		1.0
//  Purpose:      	Log Form View
//******************************************************************************
  TfmLog = class(TForm)
    grLog: TStringGrid;
    sbLog: TStatusBar;
    mmLog: TMainMenu;
    mnuFile: TMenuItem;
    mnuReload: TMenuItem;
    mnuN1: TMenuItem;
    mnuDeleteClose: TMenuItem;
    mnuClose: TMenuItem;
    mnuRecord: TMenuItem;
    mnuShow: TMenuItem;
    procedure FormResize(Sender: TObject);
    procedure grLogDrawCell(Sender: TObject; Col, Row: Integer; Rect: TRect; State: TGridDrawState);
    procedure grLogSelectCell(Sender: TObject; Col, Row: Integer; var CanSelect: Boolean);
    procedure mnuShowClick(Sender: TObject);
    procedure mnuDeleteCloseClick(Sender: TObject);
    procedure mnuCloseClick(Sender: TObject);
    procedure mnuReloadClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end; // TfmLog


procedure Register;

implementation
{$R *.DFM}
{$R *.DCR}
{$R *.RES}

var
  tmpLog: TLog;
  fmLog: TfmLog;

procedure Register;
begin
  RegisterComponents('My Comp', [TLog]);
  RegisterPropertyEditor(TypeInfo(Cardinal), TLog, 'Information', TInformationProperty);
  RegisterComponentEditor(TLog, TInformationEditor);
end; // Procedure Register

//******************************************************************************
//  Function:	        LogTokenAt
//  Ver:  		1.0
//  Purpose:  		General function for string tokenizing
//******************************************************************************
function LogTokenAt(const S: string; Seperator: Char; At: Integer): string;
var
  j,i: Integer;
begin
  Result:='';
  j := 1;
  i := 0;
  while (i<=At ) and (j<=Length(S)) do
  begin
    if S[j]=Seperator then
       Inc(i)
    else if i = At then
       Result:=Result+S[j];
    Inc(j);
  end;
end; // function LogTokenAt

//******************************************************************************
//  CollectionItem:	TLogItem
//  Ver:  		1.0
//  Purpose:  		TLogItem Methods
//******************************************************************************
constructor TLogItem.Create(Collection: TCollection);
begin
  inherited Create(Collection);
  FWidth:=70;
end; // TLogItem.Create

destructor TLogItem.Destroy;
begin
  inherited Destroy;
end; // TLogItem.Destroy

function TLogItem.GetDisplayName: string;
begin
  // Note: Inherited default behavior of GetDisplayName is to
  // return the classname.
  Result := FFieldName;
  if Result = '' then Result := inherited GetDisplayName;
end; // TLogItem.GetDisplayName


//******************************************************************************
//  Collection:		TLogItems
//  Ver:  		1.0
//  Purpose:  		TLogItems Methods
//******************************************************************************
constructor TLogItems.Create(Log: TLog);
begin
  inherited Create(TLogItem);
  FLog := Log;
end; // TLogItems.Create

function TLogItems.Add: TLogItem;
begin
  Result := TLogItem(inherited Add);
end; // TLogItems.Add

function TLogItems.GetItem(Index: Integer): TLogItem;
begin
  Result := TLogItem(inherited GetItem(Index));
end; // TLogItems.GetItem

procedure TLogItems.SetItem(Index: Integer; Value: TLogItem);
begin
  inherited SetItem(Index, Value);
end; // TLogItems.SetItem

function TLogItems.GetOwner: TPersistent;
begin
  // Note: You must override GetOwner in Delphi 3.x to get
  // correct streaming behavior.
  Result := FLog;
end; // TLogItems.GetOwner


//******************************************************************************
//  Constructor:	TLog.Create
//  Ver:  		1.0
//  Purpose:            TLog Constructor
//******************************************************************************
constructor TLog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FItems:=TLogItems.Create (Self);
  FCsvSeparator:=DEFAULT_SEPARATOR;
  FHeight:=380;
  FWidth:=500;
end; // TLog.Create

//******************************************************************************
//  Destructor:		TLog.Destroy
//  Ver:  		1.0
//  Purpose:  		TLog Destructor
//******************************************************************************
destructor TLog.Destroy;
begin
  FItems.Free;
  FItems:=nil;
  inherited Destroy;
end; // TLog.Destroy


//******************************************************************************
//  Function: 		TLog.WriteLog
//  Ver:  		1.0
//  Purpose:            Write a log message
//******************************************************************************
function TLog.WriteLog (LogMessage: integer; Values : array of string): boolean;
var
  tmpFile: TextFile;
  tmpStr: string;
  tiCount: integer;
  tiItemsCount: integer;
  Buffer: array [0..127] of Char;
  BufferSize: Integer;
begin
  Result:=False;

  // Check parameters number
  if (not (Assigned (FItems))) or (FItems.Count<=0) then Exit;
  tiItemsCount:=0;
  for tiCount:=0 to pred (FItems.Count) do
    if FItems[tiCount].FieldKind in [lfString, lfNumber] then inc (tiItemsCount);
  // Exit if Values & ItemsCount don't match
  if tiItemsCount <> High (Values) + 1 then Exit;

  {$I-}
  // Open File
  AssignFile (tmpFile, FFileName);
  Append (tmpFile);
  if IOResult<>0 then
  begin
    Rewrite (tmpFile);
    if IOResult<>0 then Exit;
  end;

  // Write Fields
  tiItemsCount:=0;
  tmpStr:=IntToStr (LogMessage) + Separator;
  for tiCount:=0 to pred (FItems.Count) do
  begin
    case FItems[tiCount].FieldKind of
      lfString:
        begin
         tmpStr:=tmpStr + '"' + Values[tiItemsCount] + '"' + Separator;
         Inc (tiItemsCount);
        end;
      lfNumber:
        begin
         tmpStr:=tmpStr + Values[tiItemsCount] +  Separator;
         Inc (tiItemsCount);
        end;
      lfUserName:
        begin
          // UserName
          BufferSize:=SizeOf (Buffer);
          GetUserName (Buffer, BufferSize );
          tmpStr:=tmpStr + '"' + Buffer + '"' + Separator;
        end;
      lfComputerName:
        begin
          BufferSize:=SizeOf (Buffer);
          // ComputerName
          GetComputerName (Buffer, BufferSize);
          tmpStr:=tmpStr + '"' + Buffer + '"' + Separator;
        end;
      lfAppName:
        tmpStr:=tmpStr + '"' + ExtractFileName (Application.ExeName) + '"' + Separator;
      lfDateStamp:
        tmpStr:=tmpStr + DateToStr (Date) +  Separator;
      lfTimeStamp:
        tmpStr:=tmpStr + TimeToStr (Time) +  Separator;
    end; // case
  end; // for

  // Write string & Close File
  Writeln (tmpFile, tmpStr);
  CloseFile (tmpFile);
  {$I+}
  Result:=True;
end; // function TLog.WriteLog


//******************************************************************************
//  Function: 		TLog.WriteLogInfo, TLog.WriteLogError,
//                      TLog.WriteWaring, TLog.Writeprocess
//  Ver:  		1.0
//  Purpose:            Simple wrapper for Log writing
//******************************************************************************
function TLog.WriteLogInfo (Values : array of string): boolean;
begin
  Result:=WriteLog (1, Values);
end; // function TLog.WriteLogInfo

function TLog.WriteLogError (Values : array of string): boolean;
begin
  Result:=WriteLog (2, Values);
end; // function TLog.WriteLogError

function TLog.WriteLogWarning (Values : array of string): boolean;
begin
  Result:=WriteLog (3, Values);
end; // function TLog.WriteLogWarning

function TLog.WriteLogProcess (Values : array of string): boolean;
begin
  Result:=WriteLog (4, Values);
end; // function TLog.WriteLogProcess


//******************************************************************************
//  Function: 		TLog.ReadLog
//  Ver:  		1.0
//  Purpose:            Read Log file
//******************************************************************************
function TLog.ReadLog (Grid: TStringGrid) : boolean;
var
  tmpFile: TextFile;
  tmpField,
  tmpStr: string;
  tiCount: integer;
begin
  Result:=False;
  {$I-}
    AssignFile (tmpFile, FFileName);
    Reset (tmpFile);
  {$I+}
  if IOResult<>0 then Exit;
  with Grid do
  begin
    // Set Grid
    RowCount:=1;
    ColCount:=FItems.Count + 2;
    ColWidths[0]:=70;
    for tiCount:=0 to Pred (FItems.Count) do
    begin
      Cells[tiCount+1,0]:=FItems[tiCount].DisplayName;
      ColWidths[tiCount+1]:=FItems[tiCount].Width;
    end;
    ColWidths[ColCount-1]:=100;

    // Load Grid
    while not eof (tmpFile) do
    begin
      Readln (tmpFile,tmpStr);
      RowCount:=RowCount + 1;
      Cells [0, RowCount-1]:= IntToStr(RowCount-1);
      for tiCount:=0 to Pred (FItems.Count) do
      begin
        tmpField:='';
        tmpField:=LogTokenAt (tmpStr, Separator, tiCount+1);
        // Remove "
        if Length(tmpField) >=1 then
          if tmpField[1]='"' then tmpField:=Copy (tmpField, 2, Length(tmpField) -1);
        if Length(tmpField) >=1 then
          if tmpField[Length(tmpField)]='"' then tmpField:=Copy (tmpField, 1, Length(tmpField) -1);
        Cells [tiCount+1, RowCount-1]:=tmpField;
       end;// for
    end; // while

    Cells[0,0]:='Id';
    FixedRows:=1;
  end;
  CloseFile (tmpFile);
  Result:=True;
end; // procedure TLog.ReadLog


//******************************************************************************
//  Procedure: 		TLog.ViewLog;
//  Ver:  		1.0
//  Purpose:            Show Log Window
//******************************************************************************
procedure TLog.ViewLog;
var
  tmpForm: TfmLog;
begin
  // Check parameters number
  if (not (Assigned (FItems))) or (FItems.Count<=0) then Exit;

  try
    tmpForm:=TfmLog.Create (Application);
  except
    on E: Exception do begin
      MessageBeep(0);
      Exit;
    end;
  end; // try

  try
    with tmpForm do
    begin
      Width:=FormWidth;
      Height:=FormHeight;
      // Loop. It check the modal result to Reload or Delete the, or Exit
      repeat
        if ReadLog (grLog) then ShowModal;
        if ModalResult=mrAbort then DeleteFile (FFileName);
      until (ModalResult <> mrRetry);
    end; // with
  finally
    tmpForm.Free;
    tmpForm:=nil;
  end; // try
end; // procedure TLog.ViewLog


//******************************************************************************
//  Property:	        TLog Properties
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
procedure TLog.SetFileName (Value: TFileName);
begin
  // Delete ol Log File
  if (FDeleteOnChange) and (Value <> FFileName) then DeleteFile (FFileName);
  FFileName:=Value;
end; // procedure TLog.SetFileName

procedure TLog.SetItems(Value: TLogItems);
begin
  FItems.Assign(Value);
end; // TLog.SetItems


//******************************************************************************
//  Function: 		TInformation Editor
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
function TInformationEditor.GetVerbCount: Integer;
begin
  Result:= 4;
end; // TInformationEditor.GetVerbCount

function TInformationEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result:= 'TLog v. '+ VERSION_ID;
    1: Result:= '(c) 1998 by Gianni Giorgetti soft';
    2: Result:= '-';
    3: Result:= 'View Log...';
  end; // case
end; // TInformationEditor.GetVerb

procedure TInformationEditor.ExecuteVerb(Index: Integer);
begin
  case index of
   0,1: About;
   3: Edit;
  end; // case
end; // TInformationEditor.ExecuteVerb

procedure TInformationEditor.Edit;
begin
  fmLog:= TfmLog.Create(Application);
  try
    tmpLog:=Component as TLog;
    tmpLog.ViewLog;
  finally
   fmLog.Free;
  end;
end; // TInformationEditor.Edit

procedure TInformationEditor.About;
var
  tmpForm: TForm;
begin
  tmpForm:=TForm.Create(Application);
  with tmpForm do
  try
    BorderStyle:=bsDialog;
    Position:=poScreenCenter;
    Width:=400;
    Height:=120;
    Caption:='About TLog Component';
    with TImage.Create (tmpForm) do
    begin
      Top:=20;
      Left:=20;
      Transparent:=True;
      Parent:=tmpForm;
      Picture.Bitmap.Handle:=LoadBitmap(HInstance,'LOG');
    end;  // with
    with TLabel.Create(tmpForm) do
    begin
      Parent:=tmpForm;
      Left:=80;
      Top:=20;
      Caption:='TLog Component';
    end; // with
    with TLabel.Create(tmpForm) do
    begin
      Parent:=tmpForm;
      Left:=80;
      Top:=35;
      Caption:='Ver. 1.0';
    end; // with
    with TLabel.Create(tmpForm) do
    begin
      Parent:=tmpForm;
      Left:=80;
      Top:=55;
      Caption:='CopyRight (c) 1988, Gianni Giorgetti Soft';
    end; // with
    with TButton.Create(tmpForm) do
    begin
      Parent:=tmpForm;
      Left:=305;
      Top:=20;
      ModalResult:=mrOk;
      Caption:='&OK';
    end; // with

    ShowModal;
  finally
    Free;
  end; // try
end; // TInformationEditor.Edit


//******************************************************************************
//  Function: 		TInformationProperty
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
function TInformationProperty.GetAttributes: TPropertyAttributes;
begin
  Result:= inherited GetAttributes+[paReadOnly, paDialog];
end; // TInformationProperty.GetAttributes

function TInformationProperty.GetName: string;
begin
  Result:= 'View Log';
end; // TInformationProperty.GetName

function TInformationProperty.GetValue: string;
begin
  Result:= '(Double-click here)';
end; // TInformationProperty.GetValue

procedure TInformationProperty.Edit;
begin
  fmLog:= TfmLog.Create(Application);
  try
    tmpLog:=TComponent(GetComponent(0)) as TLog;
    tmpLog.ViewLog;
  finally
   fmLog.Free;
  end; // try
end; // TInformationProperty.Edit


//******************************************************************************
//  Event:              TfmLog.FormResize
//  Ver:                1.0
//  Purpose:            Set scrollbars on form resizing
//******************************************************************************
procedure TfmLog.FormResize(Sender: TObject);
var
  tiCount, tiWidth: integer;
begin
  tiWidth:=Width - grLog.Width;
  for tiCount:=0 to grLog.ColCount - 2 do tiWidth:=tiWidth + grLog.ColWidths [tiCount];
  if Width > tiWidth + 20 then grLog.ScrollBars:=ssVertical
    else grLog.ScrollBars:=ssBoth;
end; // procedure TfmLog.FormResize


//******************************************************************************
//  Event: 		TfmLog.grLogSelectCell
//  Ver:  		1.0
//  Purpose:            Set row count in StatusBar
//******************************************************************************
procedure TfmLog.grLogSelectCell(Sender: TObject; Col, Row: Integer; var CanSelect: Boolean);
begin
  sbLog.Panels[0].Text:='Record '+IntToStr (grLog.Row)+' of '+IntToStr (grLog.RowCount - 1)+'      ';;
end; // TfmLog.grLogSelectCell


//******************************************************************************
//  Event: 		TfmLog.grLogDrawCell
//  Ver:  		1.0
//  Purpose:            Paint the bitmap at first Column
//******************************************************************************
procedure TfmLog.grLogDrawCell(Sender: TObject; Col, Row: Integer;
  Rect: TRect; State: TGridDrawState);
var
  Bitmap: TBitmap;
  tiOffset: integer;
  tiHeight: integer;
begin
  with (Sender as TStringGrid).Canvas do
  if (Col = 0) and (Row>0) then
  begin
    Bitmap := TBitmap.Create;
    case StrToIntDef (TStringGrid (Sender).Cells[Col,Row],1) of
     2: Bitmap.Handle := LoadBitmap(HInstance,'WARNING');
     3: Bitmap.Handle := LoadBitmap(HInstance,'ERROR');
     4: Bitmap.Handle := LoadBitmap(HInstance,'PROCESS');
     else Bitmap.Handle := LoadBitmap(HInstance,'INFO');
    end; // case

    tiOffset:=0;
    tiHeight:=TStringGrid (Sender).DefaultRowHeight;
    if (Bitmap <> nil) then
    begin
      StretchDraw(Bounds(Rect.Left, Rect.Top, tiHeight, tiHeight), Bitmap);
      tiOffset:= tiHeight + 8;
    end; // if
    TextOut(Rect.Left + tiOffset, Rect.Top + 2, TStringGrid (Sender).Cells[Col,Row]);
    Bitmap.Free;
  end; // with

end; // procedure TfmLog.grLogDrawCell


//******************************************************************************
//  Event: 		TfmLog.mnuShowClick
//  Ver:  		1.0
//  Purpose:            Runtime Create & Show the Log View form
//******************************************************************************
procedure TfmLog.mnuShowClick(Sender: TObject);
var
  tmpForm: TForm;
  tmpScrollBox: TScrollBox;
  tiCount: integer;
begin
  tmpForm:=TForm.Create (Application);
  with tmpForm do
  begin
    try
      Width:=400;
      Height:=340;
      BorderStyle:=bsDialog;
      Position:=poScreenCenter;
      Caption:='Log File Record ' + IntToStr (grLog.Row) + ' of ' + IntToStr (grLog.RowCount - 1);
      with TImage.Create (tmpForm) do
      begin
        Top:=10;
        Left:=tmpForm.Width - 50;
        Transparent:=True;
        Parent:=tmpForm;
        case StrToIntDef (grLog.Cells[0,grLog.Row],1) of
          2: Picture.Bitmap.Handle:=LoadBitmap(HInstance,'WARNING');
          3: Picture.Bitmap.Handle:=LoadBitmap(HInstance,'ERROR');
          4: Picture.Bitmap.Handle:=LoadBitmap(HInstance,'PROCESS');
          else Picture.Bitmap.Handle:=LoadBitmap(HInstance,'INFO');
        end; // case
      end; // with
      tmpScrollBox:=TScrollBox.Create (tmpForm);
      with tmpScrollBox do
      begin
        Top:=50;
        Left:=10;
        Width:=tmpForm.Width-25;
        Height:=tmpForm.Height-120;
        VertScrollBar.Visible:=True;
        Parent:=tmpForm;
      end; // with
      for tiCount:=1 to grLog.ColCount - 2 do
      begin
        with TLabel.Create (tmpScrollBox) do
        begin
          Caption:=grLog.Cells[tiCount,0]+':';
          Parent:=tmpScrollBox;
          Left:=20;
          Top:=tiCount * 20 - 10;
        end; // with
        with TLabel.Create (tmpScrollBox) do
        begin
          Caption:=grLog.Cells[tiCount,grLog.Row];
          Parent:=tmpScrollBox;
          Left:=110;
          Top:=tiCount * 20 - 10;
        end; // with
      end; // for
      with TButton.Create (tmpForm) do
      begin
        Caption:='&Close';
        ModalResult:=mrOK;
        Top:=tmpForm.Height - 60;
        Left:=tmpForm.Width - 90;
        Parent:=tmpForm;
      end; // with
      ShowModal;
    finally;
      Free;
    end; // try
  end; // with
end; // TfmLog.mnuShowClick

//******************************************************************************
//  Event: 		TfmLog.mnuReloadClick
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
procedure TfmLog.mnuReloadClick(Sender: TObject);
begin
  ModalResult:=mrRetry;
end; // TfmLog.mnuReloadClick


//******************************************************************************
//  Event: 		TfmLog.mnuDeleteCloseClick
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
procedure TfmLog.mnuDeleteCloseClick(Sender: TObject);
begin
  ModalResult:=mrAbort;
end; // TfmLog.mnuDeleteCloseClick


//******************************************************************************
//  Event: 		TfmLog.mnuCloseClick
//  Ver:  		1.0
//  Purpose:
//******************************************************************************
procedure TfmLog.mnuCloseClick(Sender: TObject);
begin
  ModalResult:=mrOK;
end; // TfmLog.mnuCloseClick

end. // Unit MyLog
